summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/worktoolbar.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/worktoolbar.h')
-rw-r--r--umbrello/umbrello/worktoolbar.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/umbrello/umbrello/worktoolbar.h b/umbrello/umbrello/worktoolbar.h
index 01b7c9a3..410644d2 100644
--- a/umbrello/umbrello/worktoolbar.h
+++ b/umbrello/umbrello/worktoolbar.h
@@ -47,9 +47,9 @@ public:
/**
* Creates a work tool bar.
*
* @param tqparentWindow The tqparent of the toolbar.
*/
- WorkToolBar(TQMainWindow *tqparentWindow, const char *name);
+ WorkToolBar(TQMainWindow *parentWindow, const char *name);
/**
* Standard deconstructor.
@@ -47,9 +47,9 @@ public:
* Creates a work tool bar.
*
- * @param tqparentWindow The tqparent of the toolbar.
+ * @param parentWindow The tqparent of the toolbar.
*/